# pyTenjin Examples

release: 1.0.0

## Table of Contents

### [1. Bordered Table](examples/01-bordered-table.md)
Template rendering with loops and conditional styling.

### [2. Form](examples/02-form.md)
Form handling with partial templates, layout templates, and template short names.

### [3. Preprocessing](examples/03-preprocessing.md)
Template preprocessing with loop expansion and parameterized helper functions.

### [4. Google App Engine](examples/04-google-app-engine.md) *(legacy)*
Example application for Google App Engine using Tenjin. Note: GAE's legacy webapp framework is no longer supported.
